/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.model.util;

/**
 * Each identifiable entity class should extend this.
 * The identifiable classes must pass a discriminator String to its ctor,
 * that will be used to generate the integer ID.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public abstract class IdentifiedEntity {
    /**
     * Unique identifier that is generated from
     * a discriminator in the ctor.
     * @see #Identified(String)
     */
    private int id;

    /**
     * @param discriminator must be unique and will be used to generate the integer ID.
     * @see #getId()
     */
    public IdentifiedEntity(String discriminator) {
        this.id = (discriminator == null) ? 0 : discriminator.hashCode();
    }

    public int getId() {
        return id;
    }
}
