/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.portlet;

import hu.midori.kosmos.portlet.util.PortletUtils;

import java.util.List;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletConfig;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Each Kosmos portlet must extend this baseclass.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public abstract class AbstractKosmosPortlet extends GenericPortlet {
    private final static Log log = LogFactory.getLog(AbstractKosmosPortlet.class);
    
    /** Renders a JSP and sets the portlet title. */
    protected void renderJsp(RenderRequest request, RenderResponse response, String jspName, String title) {
        response.setTitle(title);
        renderJsp(request, response, jspName);
    }    
    
    /** Renders a JSP. */
    protected void renderJsp(RenderRequest request, RenderResponse response, String jspName) {
        response.setContentType("text/html");
        PortletRequestDispatcher rd = getPortletContext().getRequestDispatcher(jspName);
        try {
            rd.include(request, response);
        } catch(Exception ex) {
            log.error("Unable to include", ex);
        }        
    }

	/** 
	 * This dummy method needs only to make Liferay happy: Liferay will call this when 
	 * minimizing/maximizing the portlet window, and the implementation in <code>GenericPortlet</code> 
	 * simply throws an exception.  
	 */
	@Override
	public void processAction(ActionRequest arg0, ActionResponse arg1) {
		log.debug("Dummy processAction() called");
	}        

    /** Returns the appropriate portlet init parameter. */
    protected static String getMonitoredResourceInitParameter(PortletConfig config) {
    	String monitoredResource = config.getInitParameter("monitored.resource"); 
        if(StringUtils.isBlank(monitoredResource))
            throw new IllegalStateException("'monitored.resource' is a required init-param");

        return monitoredResource.trim();
    }

    /** Returns the appropriate portlet init parameter. */
    protected static String getServiceUrlInitParameter(PortletConfig config) {
        String serviceUrl = config.getInitParameter("service.url");        
        if(StringUtils.isBlank(serviceUrl))
            throw new IllegalStateException("'service.url' is a required init-param");

        return serviceUrl.trim();
    }
    
    /** Returns the appropriate portlet init parameter. */
    protected static List<String> getMonitoredUrlsInitParameter(PortletConfig config) {    
	    List<String> monitoredUrls = PortletUtils.breakCommaSeparatedString(config.getInitParameter("monitored.urls"));        
	    if(monitoredUrls.isEmpty())
	        throw new IllegalStateException("'monitored.urls' is a required init-param");
	    
	    return monitoredUrls;
    }
    
    /** Returns the appropriate portlet init parameter. */
    protected static String getFixedViewInitParameter(PortletConfig config) {
		String fixedView = config.getInitParameter("fixed.view");
		if(fixedView == null)
			return null;
		
		if((fixedView != null) && (getMonitoredUrlsInitParameter(config).size() > 1))
			throw new IllegalArgumentException("'fixed.view' can't be used with multiple items in 'monitored.urls'");
		
		return fixedView.trim();
    }    		
}
